==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/ca.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "S'ha produït un error mentre es generaven els codis de seguretat",
    "{name} backup codes" : "Codis de seguretat {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Aquests són els vostres codis de seguretat. Si us plau, deseu-los i/o imprimiu-los ja que no podreu tornar-los a llegir després",
    "Save backup codes" : "Desa els codis de seguretat",
    "Print backup codes" : "Imprimeix codis de seguretat",
    "Backup codes have been generated. {used} of {total} codes have been used." : "S'han generat els codis de seguretat. S'han fet servir {used} de {total} codis.",
    "Regenerate backup codes" : "Regenera els codis de seguretat",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si regenereu els codis de seguretat, invalidareu automàticament els codis antics.",
    "Generate backup codes" : "Genera els codis de seguretat",
    "You created two-factor backup codes for your account" : "Heu creat els codis de seguretat de dos factors per al vostre compte",
    "Second-factor backup codes" : "Codis de seguretat de segon factor",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Heu activat l'autenticació de dos factors però encara no heu generat els codis de seguretat. Aquests són necessaris per restablir l'accés al vostre compte en cas de perdre el vostre segon factor.",
    "Backup code" : "Codi de seguretat",
    "Use backup code" : "Utilitza un codi de seguretat",
    "Two factor backup codes" : "Codis de seguretat de l'autenticació en dos factors",
    "A two-factor auth backup codes provider" : "Proveïdor de codis de seguretat d'autenticació en dos factors",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Feu servir un dels codis de seguretat que heu desat quan he configurat l’autenticació de dos factors.",
    "Submit" : "Envia",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "S'han generat els codis de seguretat. S'han fet servir {{used}} de {{total}} codis.",
    "Nextcloud backup codes" : "Codis de seguretat de Nextcloud",
    "activated" : "activat",
    "updated" : "actualitzat",
    "mounted" : "muntat",
    "deactivated" : "desactivat",
    "beforeCreate" : "beforeCreate",
    "created" : "creat",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destruït",
    "beforeMount" : "beforeMount",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Heu activat l'autenticació de dos factors, però encara no heu generat els codis de seguretat. Assegureu-vos de fer-ho en cas de perdre l'accés al segon factor."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/ca.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "function" : "funció",
    "_" : "_",
    "An error occurred while generating your backup codes" : "S'ha produït un error mentre es generaven els codis de seguretat",
    "{name} backup codes" : "Codis de seguretat {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Aquests són els vostres codis de seguretat. Si us plau, deseu-los i/o imprimiu-los ja que no podreu tornar-los a llegir després",
    "Save backup codes" : "Desa els codis de seguretat",
    "Print backup codes" : "Imprimeix codis de seguretat",
    "Backup codes have been generated. {used} of {total} codes have been used." : "S'han generat els codis de seguretat. S'han fet servir {used} de {total} codis.",
    "Regenerate backup codes" : "Regenera els codis de seguretat",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si regenereu els codis de seguretat, invalidareu automàticament els codis antics.",
    "Generate backup codes" : "Genera els codis de seguretat",
    "You created two-factor backup codes for your account" : "Heu creat els codis de seguretat de dos factors per al vostre compte",
    "Second-factor backup codes" : "Codis de seguretat de segon factor",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Heu activat l'autenticació de dos factors però encara no heu generat els codis de seguretat. Aquests són necessaris per restablir l'accés al vostre compte en cas de perdre el vostre segon factor.",
    "Backup code" : "Codi de seguretat",
    "Use backup code" : "Utilitza un codi de seguretat",
    "Two factor backup codes" : "Codis de seguretat de l'autenticació en dos factors",
    "A two-factor auth backup codes provider" : "Proveïdor de codis de seguretat d'autenticació en dos factors",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Feu servir un dels codis de seguretat que heu desat quan he configurat l’autenticació de dos factors.",
    "Submit" : "Envia",
    "activated" : "activat",
    "updated" : "actualitzat",
    "mounted" : "muntat",
    "deactivated" : "desactivat",
    "beforeCreate" : "beforeCreate",
    "created" : "creat",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "destruït",
    "beforeMount" : "beforeMount",
    "Nextcloud backup codes" : "Codis de seguretat de Nextcloud",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Heu activat l'autenticació de dos factors, però encara no heu generat els codis de seguretat. Assegureu-vos de fer-ho en cas de perdre l'accés al segon factor."
},
"nplurals=2; plural=(n != 1);");
